# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/status/v3/csds.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.admin.v3 import config_dump_pb2 as envoy_dot_admin_dot_v3_dot_config__dump__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.type.matcher.v3 import node_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_node__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/status/v3/csds.proto',
  package='envoy.service.status.v3',
  syntax='proto3',
  serialized_options=b'\n%io.envoyproxy.envoy.service.status.v3B\tCsdsProtoP\001\210\001\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"envoy/service/status/v3/csds.proto\x12\x17\x65nvoy.service.status.v3\x1a envoy/admin/v3/config_dump.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a envoy/type/matcher/v3/node.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xae\x01\n\x13\x43lientStatusRequest\x12\x39\n\rnode_matchers\x18\x01 \x03(\x0b\x32\".envoy.type.matcher.v3.NodeMatcher\x12(\n\x04node\x18\x02 \x01(\x0b\x32\x1a.envoy.config.core.v3.Node:2\x9a\xc5\x88\x1e-\n+envoy.service.status.v2.ClientStatusRequest\"\x8b\x04\n\x0cPerXdsConfig\x12\x35\n\x06status\x18\x01 \x01(\x0e\x32%.envoy.service.status.v3.ConfigStatus\x12\x46\n\rclient_status\x18\x07 \x01(\x0e\x32+.envoy.service.status.v3.ClientConfigStatusB\x02\x18\x01\x12>\n\x0flistener_config\x18\x02 \x01(\x0b\x32#.envoy.admin.v3.ListenersConfigDumpH\x00\x12<\n\x0e\x63luster_config\x18\x03 \x01(\x0b\x32\".envoy.admin.v3.ClustersConfigDumpH\x00\x12\x38\n\x0croute_config\x18\x04 \x01(\x0b\x32 .envoy.admin.v3.RoutesConfigDumpH\x00\x12\x45\n\x13scoped_route_config\x18\x05 \x01(\x0b\x32&.envoy.admin.v3.ScopedRoutesConfigDumpH\x00\x12>\n\x0f\x65ndpoint_config\x18\x06 \x01(\x0b\x32#.envoy.admin.v3.EndpointsConfigDumpH\x00:+\x9a\xc5\x88\x1e&\n$envoy.service.status.v2.PerXdsConfigB\x10\n\x0eper_xds_config\"\xa0\x01\n\x0c\x43lientConfig\x12(\n\x04node\x18\x01 \x01(\x0b\x32\x1a.envoy.config.core.v3.Node\x12\x39\n\nxds_config\x18\x02 \x03(\x0b\x32%.envoy.service.status.v3.PerXdsConfig:+\x9a\xc5\x88\x1e&\n$envoy.service.status.v2.ClientConfig\"\x82\x01\n\x14\x43lientStatusResponse\x12\x35\n\x06\x63onfig\x18\x01 \x03(\x0b\x32%.envoy.service.status.v3.ClientConfig:3\x9a\xc5\x88\x1e.\n,envoy.service.status.v2.ClientStatusResponse*K\n\x0c\x43onfigStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06SYNCED\x10\x01\x12\x0c\n\x08NOT_SENT\x10\x02\x12\t\n\x05STALE\x10\x03\x12\t\n\x05\x45RROR\x10\x04*c\n\x12\x43lientConfigStatus\x12\x12\n\x0e\x43LIENT_UNKNOWN\x10\x00\x12\x14\n\x10\x43LIENT_REQUESTED\x10\x01\x12\x10\n\x0c\x43LIENT_ACKED\x10\x02\x12\x11\n\rCLIENT_NACKED\x10\x03\x32\xb8\x02\n\x1c\x43lientStatusDiscoveryService\x12w\n\x12StreamClientStatus\x12,.envoy.service.status.v3.ClientStatusRequest\x1a-.envoy.service.status.v3.ClientStatusResponse\"\x00(\x01\x30\x01\x12\x9e\x01\n\x11\x46\x65tchClientStatus\x12,.envoy.service.status.v3.ClientStatusRequest\x1a-.envoy.service.status.v3.ClientStatusResponse\",\x82\xd3\xe4\x93\x02\x1d\"\x1b/v3/discovery:client_status\x82\xd3\xe4\x93\x02\x03:\x01*B?\n%io.envoyproxy.envoy.service.status.v3B\tCsdsProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_admin_dot_v3_dot_config__dump__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v3_dot_node__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])

_CONFIGSTATUS = _descriptor.EnumDescriptor(
  name='ConfigStatus',
  full_name='envoy.service.status.v3.ConfigStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SYNCED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_SENT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STALE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1291,
  serialized_end=1366,
)
_sym_db.RegisterEnumDescriptor(_CONFIGSTATUS)

ConfigStatus = enum_type_wrapper.EnumTypeWrapper(_CONFIGSTATUS)
_CLIENTCONFIGSTATUS = _descriptor.EnumDescriptor(
  name='ClientConfigStatus',
  full_name='envoy.service.status.v3.ClientConfigStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLIENT_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_REQUESTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_ACKED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_NACKED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1368,
  serialized_end=1467,
)
_sym_db.RegisterEnumDescriptor(_CLIENTCONFIGSTATUS)

ClientConfigStatus = enum_type_wrapper.EnumTypeWrapper(_CLIENTCONFIGSTATUS)
UNKNOWN = 0
SYNCED = 1
NOT_SENT = 2
STALE = 3
ERROR = 4
CLIENT_UNKNOWN = 0
CLIENT_REQUESTED = 1
CLIENT_ACKED = 2
CLIENT_NACKED = 3



_CLIENTSTATUSREQUEST = _descriptor.Descriptor(
  name='ClientStatusRequest',
  full_name='envoy.service.status.v3.ClientStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_matchers', full_name='envoy.service.status.v3.ClientStatusRequest.node_matchers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.service.status.v3.ClientStatusRequest.node', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036-\n+envoy.service.status.v2.ClientStatusRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=293,
  serialized_end=467,
)


_PERXDSCONFIG = _descriptor.Descriptor(
  name='PerXdsConfig',
  full_name='envoy.service.status.v3.PerXdsConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='envoy.service.status.v3.PerXdsConfig.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_status', full_name='envoy.service.status.v3.PerXdsConfig.client_status', index=1,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener_config', full_name='envoy.service.status.v3.PerXdsConfig.listener_config', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_config', full_name='envoy.service.status.v3.PerXdsConfig.cluster_config', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_config', full_name='envoy.service.status.v3.PerXdsConfig.route_config', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoped_route_config', full_name='envoy.service.status.v3.PerXdsConfig.scoped_route_config', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint_config', full_name='envoy.service.status.v3.PerXdsConfig.endpoint_config', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036&\n$envoy.service.status.v2.PerXdsConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='per_xds_config', full_name='envoy.service.status.v3.PerXdsConfig.per_xds_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=470,
  serialized_end=993,
)


_CLIENTCONFIG = _descriptor.Descriptor(
  name='ClientConfig',
  full_name='envoy.service.status.v3.ClientConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.service.status.v3.ClientConfig.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xds_config', full_name='envoy.service.status.v3.ClientConfig.xds_config', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036&\n$envoy.service.status.v2.ClientConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=996,
  serialized_end=1156,
)


_CLIENTSTATUSRESPONSE = _descriptor.Descriptor(
  name='ClientStatusResponse',
  full_name='envoy.service.status.v3.ClientStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.service.status.v3.ClientStatusResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036.\n,envoy.service.status.v2.ClientStatusResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1159,
  serialized_end=1289,
)

_CLIENTSTATUSREQUEST.fields_by_name['node_matchers'].message_type = envoy_dot_type_dot_matcher_dot_v3_dot_node__pb2._NODEMATCHER
_CLIENTSTATUSREQUEST.fields_by_name['node'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._NODE
_PERXDSCONFIG.fields_by_name['status'].enum_type = _CONFIGSTATUS
_PERXDSCONFIG.fields_by_name['client_status'].enum_type = _CLIENTCONFIGSTATUS
_PERXDSCONFIG.fields_by_name['listener_config'].message_type = envoy_dot_admin_dot_v3_dot_config__dump__pb2._LISTENERSCONFIGDUMP
_PERXDSCONFIG.fields_by_name['cluster_config'].message_type = envoy_dot_admin_dot_v3_dot_config__dump__pb2._CLUSTERSCONFIGDUMP
_PERXDSCONFIG.fields_by_name['route_config'].message_type = envoy_dot_admin_dot_v3_dot_config__dump__pb2._ROUTESCONFIGDUMP
_PERXDSCONFIG.fields_by_name['scoped_route_config'].message_type = envoy_dot_admin_dot_v3_dot_config__dump__pb2._SCOPEDROUTESCONFIGDUMP
_PERXDSCONFIG.fields_by_name['endpoint_config'].message_type = envoy_dot_admin_dot_v3_dot_config__dump__pb2._ENDPOINTSCONFIGDUMP
_PERXDSCONFIG.oneofs_by_name['per_xds_config'].fields.append(
  _PERXDSCONFIG.fields_by_name['listener_config'])
_PERXDSCONFIG.fields_by_name['listener_config'].containing_oneof = _PERXDSCONFIG.oneofs_by_name['per_xds_config']
_PERXDSCONFIG.oneofs_by_name['per_xds_config'].fields.append(
  _PERXDSCONFIG.fields_by_name['cluster_config'])
_PERXDSCONFIG.fields_by_name['cluster_config'].containing_oneof = _PERXDSCONFIG.oneofs_by_name['per_xds_config']
_PERXDSCONFIG.oneofs_by_name['per_xds_config'].fields.append(
  _PERXDSCONFIG.fields_by_name['route_config'])
_PERXDSCONFIG.fields_by_name['route_config'].containing_oneof = _PERXDSCONFIG.oneofs_by_name['per_xds_config']
_PERXDSCONFIG.oneofs_by_name['per_xds_config'].fields.append(
  _PERXDSCONFIG.fields_by_name['scoped_route_config'])
_PERXDSCONFIG.fields_by_name['scoped_route_config'].containing_oneof = _PERXDSCONFIG.oneofs_by_name['per_xds_config']
_PERXDSCONFIG.oneofs_by_name['per_xds_config'].fields.append(
  _PERXDSCONFIG.fields_by_name['endpoint_config'])
_PERXDSCONFIG.fields_by_name['endpoint_config'].containing_oneof = _PERXDSCONFIG.oneofs_by_name['per_xds_config']
_CLIENTCONFIG.fields_by_name['node'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._NODE
_CLIENTCONFIG.fields_by_name['xds_config'].message_type = _PERXDSCONFIG
_CLIENTSTATUSRESPONSE.fields_by_name['config'].message_type = _CLIENTCONFIG
DESCRIPTOR.message_types_by_name['ClientStatusRequest'] = _CLIENTSTATUSREQUEST
DESCRIPTOR.message_types_by_name['PerXdsConfig'] = _PERXDSCONFIG
DESCRIPTOR.message_types_by_name['ClientConfig'] = _CLIENTCONFIG
DESCRIPTOR.message_types_by_name['ClientStatusResponse'] = _CLIENTSTATUSRESPONSE
DESCRIPTOR.enum_types_by_name['ConfigStatus'] = _CONFIGSTATUS
DESCRIPTOR.enum_types_by_name['ClientConfigStatus'] = _CLIENTCONFIGSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientStatusRequest = _reflection.GeneratedProtocolMessageType('ClientStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTSTATUSREQUEST,
  '__module__' : 'envoy.service.status.v3.csds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.status.v3.ClientStatusRequest)
  })
_sym_db.RegisterMessage(ClientStatusRequest)

PerXdsConfig = _reflection.GeneratedProtocolMessageType('PerXdsConfig', (_message.Message,), {
  'DESCRIPTOR' : _PERXDSCONFIG,
  '__module__' : 'envoy.service.status.v3.csds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.status.v3.PerXdsConfig)
  })
_sym_db.RegisterMessage(PerXdsConfig)

ClientConfig = _reflection.GeneratedProtocolMessageType('ClientConfig', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTCONFIG,
  '__module__' : 'envoy.service.status.v3.csds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.status.v3.ClientConfig)
  })
_sym_db.RegisterMessage(ClientConfig)

ClientStatusResponse = _reflection.GeneratedProtocolMessageType('ClientStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTSTATUSRESPONSE,
  '__module__' : 'envoy.service.status.v3.csds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.status.v3.ClientStatusResponse)
  })
_sym_db.RegisterMessage(ClientStatusResponse)


DESCRIPTOR._options = None
_CLIENTSTATUSREQUEST._options = None
_PERXDSCONFIG.fields_by_name['client_status']._options = None
_PERXDSCONFIG._options = None
_CLIENTCONFIG._options = None
_CLIENTSTATUSRESPONSE._options = None

_CLIENTSTATUSDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='ClientStatusDiscoveryService',
  full_name='envoy.service.status.v3.ClientStatusDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1470,
  serialized_end=1782,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamClientStatus',
    full_name='envoy.service.status.v3.ClientStatusDiscoveryService.StreamClientStatus',
    index=0,
    containing_service=None,
    input_type=_CLIENTSTATUSREQUEST,
    output_type=_CLIENTSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchClientStatus',
    full_name='envoy.service.status.v3.ClientStatusDiscoveryService.FetchClientStatus',
    index=1,
    containing_service=None,
    input_type=_CLIENTSTATUSREQUEST,
    output_type=_CLIENTSTATUSRESPONSE,
    serialized_options=b'\202\323\344\223\002\035\"\033/v3/discovery:client_status\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CLIENTSTATUSDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['ClientStatusDiscoveryService'] = _CLIENTSTATUSDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/ext_authz/v4alpha/ext_authz.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from envoy.config.core.v4alpha import config_source_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2
from envoy.config.core.v4alpha import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_grpc__service__pb2
from envoy.config.core.v4alpha import http_uri_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_http__uri__pb2
from envoy.type.matcher.v4alpha import metadata_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2
from envoy.type.matcher.v4alpha import string_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2
from envoy.type.v3 import http_status_pb2 as envoy_dot_type_dot_v3_dot_http__status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/ext_authz/v4alpha/ext_authz.proto',
  package='envoy.extensions.filters.http.ext_authz.v4alpha',
  syntax='proto3',
  serialized_options=b'\n=io.envoyproxy.envoy.extensions.filters.http.ext_authz.v4alphaB\rExtAuthzProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?envoy/extensions/filters/http/ext_authz/v4alpha/ext_authz.proto\x12/envoy.extensions.filters.http.ext_authz.v4alpha\x1a$envoy/config/core/v4alpha/base.proto\x1a-envoy/config/core/v4alpha/config_source.proto\x1a,envoy/config/core/v4alpha/grpc_service.proto\x1a(envoy/config/core/v4alpha/http_uri.proto\x1a)envoy/type/matcher/v4alpha/metadata.proto\x1a\'envoy/type/matcher/v4alpha/string.proto\x1a\x1f\x65nvoy/type/v3/http_status.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xcf\x06\n\x08\x45xtAuthz\x12>\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32&.envoy.config.core.v4alpha.GrpcServiceH\x00\x12T\n\x0chttp_service\x18\x03 \x01(\x0b\x32<.envoy.extensions.filters.http.ext_authz.v4alpha.HttpServiceH\x00\x12N\n\x15transport_api_version\x18\x0c \x01(\x0e\x32%.envoy.config.core.v4alpha.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x1a\n\x12\x66\x61ilure_mode_allow\x18\x02 \x01(\x08\x12Z\n\x11with_request_body\x18\x05 \x01(\x0b\x32?.envoy.extensions.filters.http.ext_authz.v4alpha.BufferSettings\x12\x19\n\x11\x63lear_route_cache\x18\x06 \x01(\x08\x12\x32\n\x0fstatus_on_error\x18\x07 \x01(\x0b\x32\x19.envoy.type.v3.HttpStatus\x12#\n\x1bmetadata_context_namespaces\x18\x08 \x03(\t\x12K\n\x0e\x66ilter_enabled\x18\t \x01(\x0b\x32\x33.envoy.config.core.v4alpha.RuntimeFractionalPercent\x12L\n\x17\x66ilter_enabled_metadata\x18\x0e \x01(\x0b\x32+.envoy.type.matcher.v4alpha.MetadataMatcher\x12\x46\n\x0f\x64\x65ny_at_disable\x18\x0b \x01(\x0b\x32-.envoy.config.core.v4alpha.RuntimeFeatureFlag\x12 \n\x18include_peer_certificate\x18\n \x01(\x08\x12\x13\n\x0bstat_prefix\x18\r \x01(\t::\x9a\xc5\x88\x1e\x35\n3envoy.extensions.filters.http.ext_authz.v3.ExtAuthzB\n\n\x08servicesJ\x04\x08\x04\x10\x05R\tuse_alpha\"\xac\x01\n\x0e\x42ufferSettings\x12\"\n\x11max_request_bytes\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02 \x00\x12\x1d\n\x15\x61llow_partial_message\x18\x02 \x01(\x08\x12\x15\n\rpack_as_bytes\x18\x03 \x01(\x08:@\x9a\xc5\x88\x1e;\n9envoy.extensions.filters.http.ext_authz.v3.BufferSettings\"\xff\x02\n\x0bHttpService\x12\x36\n\nserver_uri\x18\x01 \x01(\x0b\x32\".envoy.config.core.v4alpha.HttpUri\x12\x13\n\x0bpath_prefix\x18\x02 \x01(\t\x12\x64\n\x15\x61uthorization_request\x18\x07 \x01(\x0b\x32\x45.envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationRequest\x12\x66\n\x16\x61uthorization_response\x18\x08 \x01(\x0b\x32\x46.envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationResponse:=\x9a\xc5\x88\x1e\x38\n6envoy.extensions.filters.http.ext_authz.v3.HttpServiceJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07\"\xe6\x01\n\x14\x41uthorizationRequest\x12\x46\n\x0f\x61llowed_headers\x18\x01 \x01(\x0b\x32-.envoy.type.matcher.v4alpha.ListStringMatcher\x12>\n\x0eheaders_to_add\x18\x02 \x03(\x0b\x32&.envoy.config.core.v4alpha.HeaderValue:F\x9a\xc5\x88\x1e\x41\n?envoy.extensions.filters.http.ext_authz.v3.AuthorizationRequest\"\xdb\x02\n\x15\x41uthorizationResponse\x12O\n\x18\x61llowed_upstream_headers\x18\x01 \x01(\x0b\x32-.envoy.type.matcher.v4alpha.ListStringMatcher\x12Y\n\"allowed_upstream_headers_to_append\x18\x03 \x01(\x0b\x32-.envoy.type.matcher.v4alpha.ListStringMatcher\x12M\n\x16\x61llowed_client_headers\x18\x02 \x01(\x0b\x32-.envoy.type.matcher.v4alpha.ListStringMatcher:G\x9a\xc5\x88\x1e\x42\n@envoy.extensions.filters.http.ext_authz.v3.AuthorizationResponse\"\xe8\x01\n\x10\x45xtAuthzPerRoute\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12\x62\n\x0e\x63heck_settings\x18\x02 \x01(\x0b\x32>.envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettingsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00:B\x9a\xc5\x88\x1e=\n;envoy.extensions.filters.http.ext_authz.v3.ExtAuthzPerRouteB\x0f\n\x08override\x12\x03\xf8\x42\x01\"\xa5\x02\n\rCheckSettings\x12q\n\x12\x63ontext_extensions\x18\x01 \x03(\x0b\x32U.envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettings.ContextExtensionsEntry\x12&\n\x1e\x64isable_request_body_buffering\x18\x02 \x01(\x08\x1a\x38\n\x16\x43ontextExtensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:?\x9a\xc5\x88\x1e:\n8envoy.extensions.filters.http.ext_authz.v3.CheckSettingsBX\n=io.envoyproxy.envoy.extensions.filters.http.ext_authz.v4alphaB\rExtAuthzProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_grpc__service__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_http__uri__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_http__status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_EXTAUTHZ = _descriptor.Descriptor(
  name='ExtAuthz',
  full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='grpc_service', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.grpc_service', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_service', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.http_service', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transport_api_version', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.transport_api_version', index=2,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_mode_allow', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.failure_mode_allow', index=3,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_request_body', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.with_request_body', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_route_cache', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.clear_route_cache', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_on_error', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.status_on_error', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_context_namespaces', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.metadata_context_namespaces', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_enabled', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.filter_enabled', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_enabled_metadata', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.filter_enabled_metadata', index=9,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deny_at_disable', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.deny_at_disable', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_peer_certificate', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.include_peer_certificate', index=11,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.stat_prefix', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0365\n3envoy.extensions.filters.http.ext_authz.v3.ExtAuthz',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='services', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.services',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=498,
  serialized_end=1345,
)


_BUFFERSETTINGS = _descriptor.Descriptor(
  name='BufferSettings',
  full_name='envoy.extensions.filters.http.ext_authz.v4alpha.BufferSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_request_bytes', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.BufferSettings.max_request_bytes', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_partial_message', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.BufferSettings.allow_partial_message', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pack_as_bytes', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.BufferSettings.pack_as_bytes', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036;\n9envoy.extensions.filters.http.ext_authz.v3.BufferSettings',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1348,
  serialized_end=1520,
)


_HTTPSERVICE = _descriptor.Descriptor(
  name='HttpService',
  full_name='envoy.extensions.filters.http.ext_authz.v4alpha.HttpService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_uri', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.HttpService.server_uri', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_prefix', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.HttpService.path_prefix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authorization_request', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.HttpService.authorization_request', index=2,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authorization_response', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.HttpService.authorization_response', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.extensions.filters.http.ext_authz.v3.HttpService',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1523,
  serialized_end=1906,
)


_AUTHORIZATIONREQUEST = _descriptor.Descriptor(
  name='AuthorizationRequest',
  full_name='envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allowed_headers', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationRequest.allowed_headers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers_to_add', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationRequest.headers_to_add', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036A\n?envoy.extensions.filters.http.ext_authz.v3.AuthorizationRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1909,
  serialized_end=2139,
)


_AUTHORIZATIONRESPONSE = _descriptor.Descriptor(
  name='AuthorizationResponse',
  full_name='envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allowed_upstream_headers', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationResponse.allowed_upstream_headers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_upstream_headers_to_append', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationResponse.allowed_upstream_headers_to_append', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_client_headers', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationResponse.allowed_client_headers', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036B\n@envoy.extensions.filters.http.ext_authz.v3.AuthorizationResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2142,
  serialized_end=2489,
)


_EXTAUTHZPERROUTE = _descriptor.Descriptor(
  name='ExtAuthzPerRoute',
  full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthzPerRoute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disabled', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthzPerRoute.disabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='check_settings', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthzPerRoute.check_settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036=\n;envoy.extensions.filters.http.ext_authz.v3.ExtAuthzPerRoute',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='override', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthzPerRoute.override',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=2492,
  serialized_end=2724,
)


_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY = _descriptor.Descriptor(
  name='ContextExtensionsEntry',
  full_name='envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettings.ContextExtensionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettings.ContextExtensionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettings.ContextExtensionsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2899,
  serialized_end=2955,
)

_CHECKSETTINGS = _descriptor.Descriptor(
  name='CheckSettings',
  full_name='envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='context_extensions', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettings.context_extensions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_request_body_buffering', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettings.disable_request_body_buffering', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036:\n8envoy.extensions.filters.http.ext_authz.v3.CheckSettings',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2727,
  serialized_end=3020,
)

_EXTAUTHZ.fields_by_name['grpc_service'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_grpc__service__pb2._GRPCSERVICE
_EXTAUTHZ.fields_by_name['http_service'].message_type = _HTTPSERVICE
_EXTAUTHZ.fields_by_name['transport_api_version'].enum_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._APIVERSION
_EXTAUTHZ.fields_by_name['with_request_body'].message_type = _BUFFERSETTINGS
_EXTAUTHZ.fields_by_name['status_on_error'].message_type = envoy_dot_type_dot_v3_dot_http__status__pb2._HTTPSTATUS
_EXTAUTHZ.fields_by_name['filter_enabled'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_EXTAUTHZ.fields_by_name['filter_enabled_metadata'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2._METADATAMATCHER
_EXTAUTHZ.fields_by_name['deny_at_disable'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._RUNTIMEFEATUREFLAG
_EXTAUTHZ.oneofs_by_name['services'].fields.append(
  _EXTAUTHZ.fields_by_name['grpc_service'])
_EXTAUTHZ.fields_by_name['grpc_service'].containing_oneof = _EXTAUTHZ.oneofs_by_name['services']
_EXTAUTHZ.oneofs_by_name['services'].fields.append(
  _EXTAUTHZ.fields_by_name['http_service'])
_EXTAUTHZ.fields_by_name['http_service'].containing_oneof = _EXTAUTHZ.oneofs_by_name['services']
_HTTPSERVICE.fields_by_name['server_uri'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_http__uri__pb2._HTTPURI
_HTTPSERVICE.fields_by_name['authorization_request'].message_type = _AUTHORIZATIONREQUEST
_HTTPSERVICE.fields_by_name['authorization_response'].message_type = _AUTHORIZATIONRESPONSE
_AUTHORIZATIONREQUEST.fields_by_name['allowed_headers'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2._LISTSTRINGMATCHER
_AUTHORIZATIONREQUEST.fields_by_name['headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._HEADERVALUE
_AUTHORIZATIONRESPONSE.fields_by_name['allowed_upstream_headers'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2._LISTSTRINGMATCHER
_AUTHORIZATIONRESPONSE.fields_by_name['allowed_upstream_headers_to_append'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2._LISTSTRINGMATCHER
_AUTHORIZATIONRESPONSE.fields_by_name['allowed_client_headers'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2._LISTSTRINGMATCHER
_EXTAUTHZPERROUTE.fields_by_name['check_settings'].message_type = _CHECKSETTINGS
_EXTAUTHZPERROUTE.oneofs_by_name['override'].fields.append(
  _EXTAUTHZPERROUTE.fields_by_name['disabled'])
_EXTAUTHZPERROUTE.fields_by_name['disabled'].containing_oneof = _EXTAUTHZPERROUTE.oneofs_by_name['override']
_EXTAUTHZPERROUTE.oneofs_by_name['override'].fields.append(
  _EXTAUTHZPERROUTE.fields_by_name['check_settings'])
_EXTAUTHZPERROUTE.fields_by_name['check_settings'].containing_oneof = _EXTAUTHZPERROUTE.oneofs_by_name['override']
_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY.containing_type = _CHECKSETTINGS
_CHECKSETTINGS.fields_by_name['context_extensions'].message_type = _CHECKSETTINGS_CONTEXTEXTENSIONSENTRY
DESCRIPTOR.message_types_by_name['ExtAuthz'] = _EXTAUTHZ
DESCRIPTOR.message_types_by_name['BufferSettings'] = _BUFFERSETTINGS
DESCRIPTOR.message_types_by_name['HttpService'] = _HTTPSERVICE
DESCRIPTOR.message_types_by_name['AuthorizationRequest'] = _AUTHORIZATIONREQUEST
DESCRIPTOR.message_types_by_name['AuthorizationResponse'] = _AUTHORIZATIONRESPONSE
DESCRIPTOR.message_types_by_name['ExtAuthzPerRoute'] = _EXTAUTHZPERROUTE
DESCRIPTOR.message_types_by_name['CheckSettings'] = _CHECKSETTINGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExtAuthz = _reflection.GeneratedProtocolMessageType('ExtAuthz', (_message.Message,), {
  'DESCRIPTOR' : _EXTAUTHZ,
  '__module__' : 'envoy.extensions.filters.http.ext_authz.v4alpha.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz)
  })
_sym_db.RegisterMessage(ExtAuthz)

BufferSettings = _reflection.GeneratedProtocolMessageType('BufferSettings', (_message.Message,), {
  'DESCRIPTOR' : _BUFFERSETTINGS,
  '__module__' : 'envoy.extensions.filters.http.ext_authz.v4alpha.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_authz.v4alpha.BufferSettings)
  })
_sym_db.RegisterMessage(BufferSettings)

HttpService = _reflection.GeneratedProtocolMessageType('HttpService', (_message.Message,), {
  'DESCRIPTOR' : _HTTPSERVICE,
  '__module__' : 'envoy.extensions.filters.http.ext_authz.v4alpha.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_authz.v4alpha.HttpService)
  })
_sym_db.RegisterMessage(HttpService)

AuthorizationRequest = _reflection.GeneratedProtocolMessageType('AuthorizationRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZATIONREQUEST,
  '__module__' : 'envoy.extensions.filters.http.ext_authz.v4alpha.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationRequest)
  })
_sym_db.RegisterMessage(AuthorizationRequest)

AuthorizationResponse = _reflection.GeneratedProtocolMessageType('AuthorizationResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZATIONRESPONSE,
  '__module__' : 'envoy.extensions.filters.http.ext_authz.v4alpha.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationResponse)
  })
_sym_db.RegisterMessage(AuthorizationResponse)

ExtAuthzPerRoute = _reflection.GeneratedProtocolMessageType('ExtAuthzPerRoute', (_message.Message,), {
  'DESCRIPTOR' : _EXTAUTHZPERROUTE,
  '__module__' : 'envoy.extensions.filters.http.ext_authz.v4alpha.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthzPerRoute)
  })
_sym_db.RegisterMessage(ExtAuthzPerRoute)

CheckSettings = _reflection.GeneratedProtocolMessageType('CheckSettings', (_message.Message,), {

  'ContextExtensionsEntry' : _reflection.GeneratedProtocolMessageType('ContextExtensionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CHECKSETTINGS_CONTEXTEXTENSIONSENTRY,
    '__module__' : 'envoy.extensions.filters.http.ext_authz.v4alpha.ext_authz_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettings.ContextExtensionsEntry)
    })
  ,
  'DESCRIPTOR' : _CHECKSETTINGS,
  '__module__' : 'envoy.extensions.filters.http.ext_authz.v4alpha.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettings)
  })
_sym_db.RegisterMessage(CheckSettings)
_sym_db.RegisterMessage(CheckSettings.ContextExtensionsEntry)


DESCRIPTOR._options = None
_EXTAUTHZ.fields_by_name['transport_api_version']._options = None
_EXTAUTHZ._options = None
_BUFFERSETTINGS.fields_by_name['max_request_bytes']._options = None
_BUFFERSETTINGS._options = None
_HTTPSERVICE._options = None
_AUTHORIZATIONREQUEST._options = None
_AUTHORIZATIONRESPONSE._options = None
_EXTAUTHZPERROUTE.oneofs_by_name['override']._options = None
_EXTAUTHZPERROUTE.fields_by_name['disabled']._options = None
_EXTAUTHZPERROUTE.fields_by_name['check_settings']._options = None
_EXTAUTHZPERROUTE._options = None
_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY._options = None
_CHECKSETTINGS._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/health_check/v4alpha/health_check.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.route.v4alpha import route_components_pb2 as envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/health_check/v4alpha/health_check.proto',
  package='envoy.extensions.filters.http.health_check.v4alpha',
  syntax='proto3',
  serialized_options=b'\n@io.envoyproxy.envoy.extensions.filters.http.health_check.v4alphaB\020HealthCheckProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nEenvoy/extensions/filters/http/health_check/v4alpha/health_check.proto\x12\x32\x65nvoy.extensions.filters.http.health_check.v4alpha\x1a\x31\x65nvoy/config/route/v4alpha/route_components.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xeb\x03\n\x0bHealthCheck\x12?\n\x11pass_through_mode\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12-\n\ncache_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x8a\x01\n\x1f\x63luster_min_healthy_percentages\x18\x04 \x03(\x0b\x32\x61.envoy.extensions.filters.http.health_check.v4alpha.HealthCheck.ClusterMinHealthyPercentagesEntry\x12:\n\x07headers\x18\x05 \x03(\x0b\x32).envoy.config.route.v4alpha.HeaderMatcher\x1a[\n!ClusterMinHealthyPercentagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.envoy.type.v3.Percent:\x02\x38\x01:@\x9a\xc5\x88\x1e;\n9envoy.extensions.filters.http.health_check.v3.HealthCheckJ\x04\x08\x02\x10\x03\x42^\n@io.envoyproxy.envoy.extensions.filters.http.health_check.v4alphaB\x10HealthCheckProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_percent__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY = _descriptor.Descriptor(
  name='ClusterMinHealthyPercentagesEntry',
  full_name='envoy.extensions.filters.http.health_check.v4alpha.HealthCheck.ClusterMinHealthyPercentagesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.filters.http.health_check.v4alpha.HealthCheck.ClusterMinHealthyPercentagesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.extensions.filters.http.health_check.v4alpha.HealthCheck.ClusterMinHealthyPercentagesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=689,
  serialized_end=780,
)

_HEALTHCHECK = _descriptor.Descriptor(
  name='HealthCheck',
  full_name='envoy.extensions.filters.http.health_check.v4alpha.HealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pass_through_mode', full_name='envoy.extensions.filters.http.health_check.v4alpha.HealthCheck.pass_through_mode', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cache_time', full_name='envoy.extensions.filters.http.health_check.v4alpha.HealthCheck.cache_time', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_min_healthy_percentages', full_name='envoy.extensions.filters.http.health_check.v4alpha.HealthCheck.cluster_min_healthy_percentages', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.extensions.filters.http.health_check.v4alpha.HealthCheck.headers', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036;\n9envoy.extensions.filters.http.health_check.v3.HealthCheck',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=852,
)

_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY.fields_by_name['value'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._PERCENT
_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY.containing_type = _HEALTHCHECK
_HEALTHCHECK.fields_by_name['pass_through_mode'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HEALTHCHECK.fields_by_name['cache_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['cluster_min_healthy_percentages'].message_type = _HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY
_HEALTHCHECK.fields_by_name['headers'].message_type = envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2._HEADERMATCHER
DESCRIPTOR.message_types_by_name['HealthCheck'] = _HEALTHCHECK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HealthCheck = _reflection.GeneratedProtocolMessageType('HealthCheck', (_message.Message,), {

  'ClusterMinHealthyPercentagesEntry' : _reflection.GeneratedProtocolMessageType('ClusterMinHealthyPercentagesEntry', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY,
    '__module__' : 'envoy.extensions.filters.http.health_check.v4alpha.health_check_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.health_check.v4alpha.HealthCheck.ClusterMinHealthyPercentagesEntry)
    })
  ,
  'DESCRIPTOR' : _HEALTHCHECK,
  '__module__' : 'envoy.extensions.filters.http.health_check.v4alpha.health_check_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.health_check.v4alpha.HealthCheck)
  })
_sym_db.RegisterMessage(HealthCheck)
_sym_db.RegisterMessage(HealthCheck.ClusterMinHealthyPercentagesEntry)


DESCRIPTOR._options = None
_HEALTHCHECK_CLUSTERMINHEALTHYPERCENTAGESENTRY._options = None
_HEALTHCHECK.fields_by_name['pass_through_mode']._options = None
_HEALTHCHECK._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/route/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.route import route_components_pb2 as envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2

from envoy.api.v2.route.route_components_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/route/route.proto',
  package='envoy.api.v2.route',
  syntax='proto3',
  serialized_options=b'\n io.envoyproxy.envoy.api.v2.routeB\nRouteProtoP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65nvoy/api/v2/route/route.proto\x12\x12\x65nvoy.api.v2.route\x1a)envoy/api/v2/route/route_components.protoB0\n io.envoyproxy.envoy.api.v2.routeB\nRouteProtoP\x01P\x00\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2.DESCRIPTOR,],
  public_dependencies=[envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/address.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import socket_option_pb2 as envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/core/address.proto',
  package='envoy.api.v2.core',
  syntax='proto3',
  serialized_options=b'\n\037io.envoyproxy.envoy.api.v2.coreB\014AddressProtoP\001\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x65nvoy/api/v2/core/address.proto\x12\x11\x65nvoy.api.v2.core\x1a%envoy/api/v2/core/socket_option.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"5\n\x04Pipe\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x16\n\x04mode\x18\x02 \x01(\rB\x08\xfa\x42\x05*\x03\x18\xff\x03\"\x88\x02\n\rSocketAddress\x12\x45\n\x08protocol\x18\x01 \x01(\x0e\x32).envoy.api.v2.core.SocketAddress.ProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x1f\n\nport_value\x18\x03 \x01(\rB\t\xfa\x42\x06*\x04\x18\xff\xff\x03H\x00\x12\x14\n\nnamed_port\x18\x04 \x01(\tH\x00\x12\x15\n\rresolver_name\x18\x05 \x01(\t\x12\x13\n\x0bipv4_compat\x18\x06 \x01(\x08\"\x1c\n\x08Protocol\x12\x07\n\x03TCP\x10\x00\x12\x07\n\x03UDP\x10\x01\x42\x15\n\x0eport_specifier\x12\x03\xf8\x42\x01\"\xb6\x01\n\x0cTcpKeepalive\x12\x36\n\x10keepalive_probes\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x34\n\x0ekeepalive_time\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x38\n\x12keepalive_interval\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\"\xb7\x01\n\nBindConfig\x12\x42\n\x0esource_address\x18\x01 \x01(\x0b\x32 .envoy.api.v2.core.SocketAddressB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12,\n\x08\x66reebind\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x0esocket_options\x18\x03 \x03(\x0b\x32\x1f.envoy.api.v2.core.SocketOption\"~\n\x07\x41\x64\x64ress\x12:\n\x0esocket_address\x18\x01 \x01(\x0b\x32 .envoy.api.v2.core.SocketAddressH\x00\x12\'\n\x04pipe\x18\x02 \x01(\x0b\x32\x17.envoy.api.v2.core.PipeH\x00\x42\x0e\n\x07\x61\x64\x64ress\x12\x03\xf8\x42\x01\"h\n\tCidrRange\x12\x1f\n\x0e\x61\x64\x64ress_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12:\n\nprefix_len\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05*\x03\x18\x80\x01\x42U\n\x1fio.envoyproxy.envoy.api.v2.coreB\x0c\x41\x64\x64ressProtoP\x01\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_SOCKETADDRESS_PROTOCOL = _descriptor.EnumDescriptor(
  name='Protocol',
  full_name='envoy.api.v2.core.SocketAddress.Protocol',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TCP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UDP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=482,
  serialized_end=510,
)
_sym_db.RegisterEnumDescriptor(_SOCKETADDRESS_PROTOCOL)


_PIPE = _descriptor.Descriptor(
  name='Pipe',
  full_name='envoy.api.v2.core.Pipe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.api.v2.core.Pipe.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='envoy.api.v2.core.Pipe.mode', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005*\003\030\377\003', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=266,
)


_SOCKETADDRESS = _descriptor.Descriptor(
  name='SocketAddress',
  full_name='envoy.api.v2.core.SocketAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol', full_name='envoy.api.v2.core.SocketAddress.protocol', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='envoy.api.v2.core.SocketAddress.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_value', full_name='envoy.api.v2.core.SocketAddress.port_value', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030\377\377\003', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='named_port', full_name='envoy.api.v2.core.SocketAddress.named_port', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolver_name', full_name='envoy.api.v2.core.SocketAddress.resolver_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_compat', full_name='envoy.api.v2.core.SocketAddress.ipv4_compat', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SOCKETADDRESS_PROTOCOL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='port_specifier', full_name='envoy.api.v2.core.SocketAddress.port_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=269,
  serialized_end=533,
)


_TCPKEEPALIVE = _descriptor.Descriptor(
  name='TcpKeepalive',
  full_name='envoy.api.v2.core.TcpKeepalive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keepalive_probes', full_name='envoy.api.v2.core.TcpKeepalive.keepalive_probes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keepalive_time', full_name='envoy.api.v2.core.TcpKeepalive.keepalive_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keepalive_interval', full_name='envoy.api.v2.core.TcpKeepalive.keepalive_interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=718,
)


_BINDCONFIG = _descriptor.Descriptor(
  name='BindConfig',
  full_name='envoy.api.v2.core.BindConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_address', full_name='envoy.api.v2.core.BindConfig.source_address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='freebind', full_name='envoy.api.v2.core.BindConfig.freebind', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='socket_options', full_name='envoy.api.v2.core.BindConfig.socket_options', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=721,
  serialized_end=904,
)


_ADDRESS = _descriptor.Descriptor(
  name='Address',
  full_name='envoy.api.v2.core.Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='socket_address', full_name='envoy.api.v2.core.Address.socket_address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pipe', full_name='envoy.api.v2.core.Address.pipe', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='address', full_name='envoy.api.v2.core.Address.address',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=906,
  serialized_end=1032,
)


_CIDRRANGE = _descriptor.Descriptor(
  name='CidrRange',
  full_name='envoy.api.v2.core.CidrRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_prefix', full_name='envoy.api.v2.core.CidrRange.address_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix_len', full_name='envoy.api.v2.core.CidrRange.prefix_len', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005*\003\030\200\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1034,
  serialized_end=1138,
)

_SOCKETADDRESS.fields_by_name['protocol'].enum_type = _SOCKETADDRESS_PROTOCOL
_SOCKETADDRESS_PROTOCOL.containing_type = _SOCKETADDRESS
_SOCKETADDRESS.oneofs_by_name['port_specifier'].fields.append(
  _SOCKETADDRESS.fields_by_name['port_value'])
_SOCKETADDRESS.fields_by_name['port_value'].containing_oneof = _SOCKETADDRESS.oneofs_by_name['port_specifier']
_SOCKETADDRESS.oneofs_by_name['port_specifier'].fields.append(
  _SOCKETADDRESS.fields_by_name['named_port'])
_SOCKETADDRESS.fields_by_name['named_port'].containing_oneof = _SOCKETADDRESS.oneofs_by_name['port_specifier']
_TCPKEEPALIVE.fields_by_name['keepalive_probes'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_TCPKEEPALIVE.fields_by_name['keepalive_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_TCPKEEPALIVE.fields_by_name['keepalive_interval'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_BINDCONFIG.fields_by_name['source_address'].message_type = _SOCKETADDRESS
_BINDCONFIG.fields_by_name['freebind'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_BINDCONFIG.fields_by_name['socket_options'].message_type = envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2._SOCKETOPTION
_ADDRESS.fields_by_name['socket_address'].message_type = _SOCKETADDRESS
_ADDRESS.fields_by_name['pipe'].message_type = _PIPE
_ADDRESS.oneofs_by_name['address'].fields.append(
  _ADDRESS.fields_by_name['socket_address'])
_ADDRESS.fields_by_name['socket_address'].containing_oneof = _ADDRESS.oneofs_by_name['address']
_ADDRESS.oneofs_by_name['address'].fields.append(
  _ADDRESS.fields_by_name['pipe'])
_ADDRESS.fields_by_name['pipe'].containing_oneof = _ADDRESS.oneofs_by_name['address']
_CIDRRANGE.fields_by_name['prefix_len'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
DESCRIPTOR.message_types_by_name['Pipe'] = _PIPE
DESCRIPTOR.message_types_by_name['SocketAddress'] = _SOCKETADDRESS
DESCRIPTOR.message_types_by_name['TcpKeepalive'] = _TCPKEEPALIVE
DESCRIPTOR.message_types_by_name['BindConfig'] = _BINDCONFIG
DESCRIPTOR.message_types_by_name['Address'] = _ADDRESS
DESCRIPTOR.message_types_by_name['CidrRange'] = _CIDRRANGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Pipe = _reflection.GeneratedProtocolMessageType('Pipe', (_message.Message,), {
  'DESCRIPTOR' : _PIPE,
  '__module__' : 'envoy.api.v2.core.address_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.core.Pipe)
  })
_sym_db.RegisterMessage(Pipe)

SocketAddress = _reflection.GeneratedProtocolMessageType('SocketAddress', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETADDRESS,
  '__module__' : 'envoy.api.v2.core.address_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.core.SocketAddress)
  })
_sym_db.RegisterMessage(SocketAddress)

TcpKeepalive = _reflection.GeneratedProtocolMessageType('TcpKeepalive', (_message.Message,), {
  'DESCRIPTOR' : _TCPKEEPALIVE,
  '__module__' : 'envoy.api.v2.core.address_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.core.TcpKeepalive)
  })
_sym_db.RegisterMessage(TcpKeepalive)

BindConfig = _reflection.GeneratedProtocolMessageType('BindConfig', (_message.Message,), {
  'DESCRIPTOR' : _BINDCONFIG,
  '__module__' : 'envoy.api.v2.core.address_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.core.BindConfig)
  })
_sym_db.RegisterMessage(BindConfig)

Address = _reflection.GeneratedProtocolMessageType('Address', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESS,
  '__module__' : 'envoy.api.v2.core.address_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.core.Address)
  })
_sym_db.RegisterMessage(Address)

CidrRange = _reflection.GeneratedProtocolMessageType('CidrRange', (_message.Message,), {
  'DESCRIPTOR' : _CIDRRANGE,
  '__module__' : 'envoy.api.v2.core.address_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.core.CidrRange)
  })
_sym_db.RegisterMessage(CidrRange)


DESCRIPTOR._options = None
_PIPE.fields_by_name['path']._options = None
_PIPE.fields_by_name['mode']._options = None
_SOCKETADDRESS.oneofs_by_name['port_specifier']._options = None
_SOCKETADDRESS.fields_by_name['protocol']._options = None
_SOCKETADDRESS.fields_by_name['address']._options = None
_SOCKETADDRESS.fields_by_name['port_value']._options = None
_BINDCONFIG.fields_by_name['source_address']._options = None
_ADDRESS.oneofs_by_name['address']._options = None
_CIDRRANGE.fields_by_name['address_prefix']._options = None
_CIDRRANGE.fields_by_name['prefix_len']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/aws_request_signing/v3/aws_request_signing.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/aws_request_signing/v3/aws_request_signing.proto',
  package='envoy.extensions.filters.http.aws_request_signing.v3',
  syntax='proto3',
  serialized_options=b'\nBio.envoyproxy.envoy.extensions.filters.http.aws_request_signing.v3B\026AwsRequestSigningProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nNenvoy/extensions/filters/http/aws_request_signing/v3/aws_request_signing.proto\x12\x34\x65nvoy.extensions.filters.http.aws_request_signing.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb0\x01\n\x11\x41wsRequestSigning\x12\x1d\n\x0cservice_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x17\n\x06region\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x14\n\x0chost_rewrite\x18\x03 \x01(\t:M\x9a\xc5\x88\x1eH\nFenvoy.config.filter.http.aws_request_signing.v2alpha.AwsRequestSigningBf\nBio.envoyproxy.envoy.extensions.filters.http.aws_request_signing.v3B\x16\x41wsRequestSigningProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_AWSREQUESTSIGNING = _descriptor.Descriptor(
  name='AwsRequestSigning',
  full_name='envoy.extensions.filters.http.aws_request_signing.v3.AwsRequestSigning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='envoy.extensions.filters.http.aws_request_signing.v3.AwsRequestSigning.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='envoy.extensions.filters.http.aws_request_signing.v3.AwsRequestSigning.region', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_rewrite', full_name='envoy.extensions.filters.http.aws_request_signing.v3.AwsRequestSigning.host_rewrite', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036H\nFenvoy.config.filter.http.aws_request_signing.v2alpha.AwsRequestSigning',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=404,
)

DESCRIPTOR.message_types_by_name['AwsRequestSigning'] = _AWSREQUESTSIGNING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AwsRequestSigning = _reflection.GeneratedProtocolMessageType('AwsRequestSigning', (_message.Message,), {
  'DESCRIPTOR' : _AWSREQUESTSIGNING,
  '__module__' : 'envoy.extensions.filters.http.aws_request_signing.v3.aws_request_signing_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.aws_request_signing.v3.AwsRequestSigning)
  })
_sym_db.RegisterMessage(AwsRequestSigning)


DESCRIPTOR._options = None
_AWSREQUESTSIGNING.fields_by_name['service_name']._options = None
_AWSREQUESTSIGNING.fields_by_name['region']._options = None
_AWSREQUESTSIGNING._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/servicecontrol/v1/metric_value.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api.servicecontrol.v1 import distribution_pb2 as google_dot_api_dot_servicecontrol_dot_v1_dot_distribution__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.type import money_pb2 as google_dot_type_dot_money__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/servicecontrol/v1/metric_value.proto',
  package='google.api.servicecontrol.v1',
  syntax='proto3',
  serialized_options=b'\n com.google.api.servicecontrol.v1B\023MetricValueSetProtoP\001ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/google/api/servicecontrol/v1/metric_value.proto\x12\x1cgoogle.api.servicecontrol.v1\x1a\x1cgoogle/api/annotations.proto\x1a/google/api/servicecontrol/v1/distribution.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/type/money.proto\"\x91\x03\n\x0bMetricValue\x12\x45\n\x06labels\x18\x01 \x03(\x0b\x32\x35.google.api.servicecontrol.v1.MetricValue.LabelsEntry\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\nbool_value\x18\x04 \x01(\x08H\x00\x12\x15\n\x0bint64_value\x18\x05 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x06 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x07 \x01(\tH\x00\x12H\n\x12\x64istribution_value\x18\x08 \x01(\x0b\x32*.google.api.servicecontrol.v1.DistributionH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x07\n\x05value\"g\n\x0eMetricValueSet\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\x12@\n\rmetric_values\x18\x02 \x03(\x0b\x32).google.api.servicecontrol.v1.MetricValueB\x88\x01\n com.google.api.servicecontrol.v1B\x13MetricValueSetProtoP\x01ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_servicecontrol_dot_v1_dot_distribution__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_type_dot_money__pb2.DESCRIPTOR,])




_METRICVALUE_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='google.api.servicecontrol.v1.MetricValue.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.api.servicecontrol.v1.MetricValue.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.servicecontrol.v1.MetricValue.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=566,
  serialized_end=611,
)

_METRICVALUE = _descriptor.Descriptor(
  name='MetricValue',
  full_name='google.api.servicecontrol.v1.MetricValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='labels', full_name='google.api.servicecontrol.v1.MetricValue.labels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='google.api.servicecontrol.v1.MetricValue.start_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='google.api.servicecontrol.v1.MetricValue.end_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='google.api.servicecontrol.v1.MetricValue.bool_value', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int64_value', full_name='google.api.servicecontrol.v1.MetricValue.int64_value', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='google.api.servicecontrol.v1.MetricValue.double_value', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='google.api.servicecontrol.v1.MetricValue.string_value', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distribution_value', full_name='google.api.servicecontrol.v1.MetricValue.distribution_value', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_METRICVALUE_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='google.api.servicecontrol.v1.MetricValue.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=219,
  serialized_end=620,
)


_METRICVALUESET = _descriptor.Descriptor(
  name='MetricValueSet',
  full_name='google.api.servicecontrol.v1.MetricValueSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metric_name', full_name='google.api.servicecontrol.v1.MetricValueSet.metric_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_values', full_name='google.api.servicecontrol.v1.MetricValueSet.metric_values', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=622,
  serialized_end=725,
)

_METRICVALUE_LABELSENTRY.containing_type = _METRICVALUE
_METRICVALUE.fields_by_name['labels'].message_type = _METRICVALUE_LABELSENTRY
_METRICVALUE.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_METRICVALUE.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_METRICVALUE.fields_by_name['distribution_value'].message_type = google_dot_api_dot_servicecontrol_dot_v1_dot_distribution__pb2._DISTRIBUTION
_METRICVALUE.oneofs_by_name['value'].fields.append(
  _METRICVALUE.fields_by_name['bool_value'])
_METRICVALUE.fields_by_name['bool_value'].containing_oneof = _METRICVALUE.oneofs_by_name['value']
_METRICVALUE.oneofs_by_name['value'].fields.append(
  _METRICVALUE.fields_by_name['int64_value'])
_METRICVALUE.fields_by_name['int64_value'].containing_oneof = _METRICVALUE.oneofs_by_name['value']
_METRICVALUE.oneofs_by_name['value'].fields.append(
  _METRICVALUE.fields_by_name['double_value'])
_METRICVALUE.fields_by_name['double_value'].containing_oneof = _METRICVALUE.oneofs_by_name['value']
_METRICVALUE.oneofs_by_name['value'].fields.append(
  _METRICVALUE.fields_by_name['string_value'])
_METRICVALUE.fields_by_name['string_value'].containing_oneof = _METRICVALUE.oneofs_by_name['value']
_METRICVALUE.oneofs_by_name['value'].fields.append(
  _METRICVALUE.fields_by_name['distribution_value'])
_METRICVALUE.fields_by_name['distribution_value'].containing_oneof = _METRICVALUE.oneofs_by_name['value']
_METRICVALUESET.fields_by_name['metric_values'].message_type = _METRICVALUE
DESCRIPTOR.message_types_by_name['MetricValue'] = _METRICVALUE
DESCRIPTOR.message_types_by_name['MetricValueSet'] = _METRICVALUESET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MetricValue = _reflection.GeneratedProtocolMessageType('MetricValue', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _METRICVALUE_LABELSENTRY,
    '__module__' : 'google.api.servicecontrol.v1.metric_value_pb2'
    # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.MetricValue.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _METRICVALUE,
  '__module__' : 'google.api.servicecontrol.v1.metric_value_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.MetricValue)
  })
_sym_db.RegisterMessage(MetricValue)
_sym_db.RegisterMessage(MetricValue.LabelsEntry)

MetricValueSet = _reflection.GeneratedProtocolMessageType('MetricValueSet', (_message.Message,), {
  'DESCRIPTOR' : _METRICVALUESET,
  '__module__' : 'google.api.servicecontrol.v1.metric_value_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.MetricValueSet)
  })
_sym_db.RegisterMessage(MetricValueSet)


DESCRIPTOR._options = None
_METRICVALUE_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1alpha1/explain.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1alpha1 import value_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_value__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/expr/v1alpha1/explain.proto',
  package='google.api.expr.v1alpha1',
  syntax='proto3',
  serialized_options=b'\n\034com.google.api.expr.v1alpha1B\014ExplainProtoP\001Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&google/api/expr/v1alpha1/explain.proto\x12\x18google.api.expr.v1alpha1\x1a$google/api/expr/v1alpha1/value.proto\"\xab\x01\n\x07\x45xplain\x12/\n\x06values\x18\x01 \x03(\x0b\x32\x1f.google.api.expr.v1alpha1.Value\x12>\n\nexpr_steps\x18\x02 \x03(\x0b\x32*.google.api.expr.v1alpha1.Explain.ExprStep\x1a+\n\x08\x45xprStep\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x13\n\x0bvalue_index\x18\x02 \x01(\x05:\x02\x18\x01\x42o\n\x1c\x63om.google.api.expr.v1alpha1B\x0c\x45xplainProtoP\x01Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_expr_dot_v1alpha1_dot_value__pb2.DESCRIPTOR,])




_EXPLAIN_EXPRSTEP = _descriptor.Descriptor(
  name='ExprStep',
  full_name='google.api.expr.v1alpha1.Explain.ExprStep',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='google.api.expr.v1alpha1.Explain.ExprStep.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_index', full_name='google.api.expr.v1alpha1.Explain.ExprStep.value_index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=274,
)

_EXPLAIN = _descriptor.Descriptor(
  name='Explain',
  full_name='google.api.expr.v1alpha1.Explain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='google.api.expr.v1alpha1.Explain.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expr_steps', full_name='google.api.expr.v1alpha1.Explain.expr_steps', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXPLAIN_EXPRSTEP, ],
  enum_types=[
  ],
  serialized_options=b'\030\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=278,
)

_EXPLAIN_EXPRSTEP.containing_type = _EXPLAIN
_EXPLAIN.fields_by_name['values'].message_type = google_dot_api_dot_expr_dot_v1alpha1_dot_value__pb2._VALUE
_EXPLAIN.fields_by_name['expr_steps'].message_type = _EXPLAIN_EXPRSTEP
DESCRIPTOR.message_types_by_name['Explain'] = _EXPLAIN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Explain = _reflection.GeneratedProtocolMessageType('Explain', (_message.Message,), {

  'ExprStep' : _reflection.GeneratedProtocolMessageType('ExprStep', (_message.Message,), {
    'DESCRIPTOR' : _EXPLAIN_EXPRSTEP,
    '__module__' : 'google.api.expr.v1alpha1.explain_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Explain.ExprStep)
    })
  ,
  'DESCRIPTOR' : _EXPLAIN,
  '__module__' : 'google.api.expr.v1alpha1.explain_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Explain)
  })
_sym_db.RegisterMessage(Explain)
_sym_db.RegisterMessage(Explain.ExprStep)


DESCRIPTOR._options = None
_EXPLAIN._options = None
# @@protoc_insertion_point(module_scope)
